
From: Tom Rini <trini@kernel.crashing.org>

The following problem was found by Giovambattista Pulcini
<gpulcini@swintel.it>, who also provided a partial patch, and this has been
verified by our time guru Gabriel Paubert <paubert@iram.es>.

The problem is that in do_settimeofday() we always set time_state to
TIME_ERROR and except on two platforms, never re-set it.  This meant that
ntp_gettime() and ntp_adjtime() always returned TIME_ERROR, incorrectly. 
Based on Gabriel's analysis, time_state is used for leap-second processing,
and ppc shouldn't be mucking with it.

From: Giovambattista Pulcini <gpulcini@swintel.it>
Signed-off-by: Tom Rini <trini@kernel.crashing.org>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/arch/ppc/kernel/time.c            |    1 -
 25-akpm/arch/ppc/platforms/chrp_time.c    |    2 --
 25-akpm/arch/ppc/platforms/gemini_setup.c |    3 ---
 3 files changed, 6 deletions(-)

diff -puN arch/ppc/kernel/time.c~ppc32-fix-a-problem-with-ntp-on-chrpgemini arch/ppc/kernel/time.c
--- 25/arch/ppc/kernel/time.c~ppc32-fix-a-problem-with-ntp-on-chrpgemini	Fri Apr  8 16:38:57 2005
+++ 25-akpm/arch/ppc/kernel/time.c	Fri Apr  8 16:38:57 2005
@@ -272,7 +272,6 @@ int do_settimeofday(struct timespec *tv)
 
 	time_adjust = 0;                /* stop active adjtime() */
 	time_status |= STA_UNSYNC;
-	time_state = TIME_ERROR;        /* p. 24, (a) */
 	time_maxerror = NTP_PHASE_LIMIT;
 	time_esterror = NTP_PHASE_LIMIT;
 	write_sequnlock_irqrestore(&xtime_lock, flags);
diff -puN arch/ppc/platforms/chrp_time.c~ppc32-fix-a-problem-with-ntp-on-chrpgemini arch/ppc/platforms/chrp_time.c
--- 25/arch/ppc/platforms/chrp_time.c~ppc32-fix-a-problem-with-ntp-on-chrpgemini	Fri Apr  8 16:38:57 2005
+++ 25-akpm/arch/ppc/platforms/chrp_time.c	Fri Apr  8 16:38:57 2005
@@ -115,8 +115,6 @@ int __chrp chrp_set_rtc_time(unsigned lo
 	chrp_cmos_clock_write(save_control, RTC_CONTROL);
 	chrp_cmos_clock_write(save_freq_select, RTC_FREQ_SELECT);
 
-	if ( (time_state == TIME_ERROR) || (time_state == TIME_BAD) )
-		time_state = TIME_OK;
 	spin_unlock(&rtc_lock);
 	return 0;
 }
diff -puN arch/ppc/platforms/gemini_setup.c~ppc32-fix-a-problem-with-ntp-on-chrpgemini arch/ppc/platforms/gemini_setup.c
--- 25/arch/ppc/platforms/gemini_setup.c~ppc32-fix-a-problem-with-ntp-on-chrpgemini	Fri Apr  8 16:38:57 2005
+++ 25-akpm/arch/ppc/platforms/gemini_setup.c	Fri Apr  8 16:38:57 2005
@@ -433,9 +433,6 @@ gemini_set_rtc_time( unsigned long now )
 	/* done writing */
 	gemini_rtc_write(reg, M48T35_RTC_CONTROL);
 
-	if ((time_state == TIME_ERROR) || (time_state == TIME_BAD))
-		time_state = TIME_OK;
-
 	return 0;
 }
 
_
